@@ -27,8 +27,9 @@ def list_or_args(keys, args):
         keys.extend(args)
     return keys
 
+
 class RedisShardAPI(object):
-    
+
     _servers = {}
 
     def __init__(self, settings=None):
@@ -130,6 +131,19 @@ class RedisShardAPI(object):
             result.append(ret_dict.get(key, None))
         return result
 
+    def mset(self, mapping):
+        """
+        Sets each key in the ``mapping`` dict to its corresponding value
+        """
+        servers = {}
+        for key, value in mapping.items():
+            server_name = self.get_server_name(key)
+            servers.setdefault(server_name, [])
+            servers[server_name].append((key, value))
+        for name, items in servers.items():
+            self.connections[name].mset(dict(items))
+        return True
+
     def flushdb(self):
         for node in self.nodes:
             server = self.connections[node]
